HPy Context
===========

The ``HPyContext`` structure is also part of the API since it provides handles
for built-in objects. For a high-level description of the context, please also
read :ref:`api:hpycontext`.

.. autocstruct:: hpy/cpython/autogen_ctx.h::_HPyContext_s
   :members:
